@@ -1,7 +1,7 @@
 package Bencher::Scenario::IPCSystemOptions;
 
-our $DATE = '2016-06-26'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -59,7 +59,7 @@ Bencher::Scenario::IPCSystemOptions - Measure the overhead of IPC::System::Optio
 
 =head1 VERSION
 
-This document describes version 0.02 of Bencher::Scenario::IPCSystemOptions (from Perl distribution Bencher-Scenario-IPCSystemOptions), released on 2016-06-26.
+This document describes version 0.03 of Bencher::Scenario::IPCSystemOptions (from Perl distribution Bencher-Scenario-IPCSystemOptions), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -73,11 +73,19 @@ To run module startup overhead benchmark:
 
 For more options (dump scenario, list/include/exclude/add participants, list/include/exclude/add datasets, etc), see L<bencher> or run C<bencher --help>.
 
+=head1 DESCRIPTION
+
+Conclusion: Testing on my system (L<IPC::System::Options> 0.24, perl: 5.22.0,
+CPU: Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores)) shows the overhead to be
+~40μs (0.04ms) so for benchmarking commands that have overhead in the range of
+10-100ms we normally don't need to worry about the overhead of
+IPC::System::Option (0.04-0.4%) when we are using default precision (~1%).
+
 =head1 BENCHMARKED MODULES
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<IPC::System::Options> 0.27
+L<IPC::System::Options> 0.29
 
 =head1 BENCHMARK PARTICIPANTS
 
@@ -107,36 +115,33 @@ L<IPC::System::Options>
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.2 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
 
 Benchmark with default options (C<< bencher -m IPCSystemOptions >>):
 
+ #table1#
  +-------------+-----------+-----------+------------+---------+---------+
  | participant | rate (/s) | time (ms) | vs_slowest |  errors | samples |
  +-------------+-----------+-----------+------------+---------+---------+
- | iso-perl    |       395 |      2.53 |       1    | 2.5e-06 |     382 |
- | core-perl   |       401 |      2.49 |       1.01 | 2.5e-06 |     452 |
- | iso-true    |       588 |      1.7  |       1.49 | 1.6e-06 |     278 |
- | core-true   |       602 |      1.66 |       1.52 | 1.6e-06 |      87 |
+ | iso-perl    |       176 |      5.67 |       1    | 5.5e-06 |     219 |
+ | core-perl   |       177 |      5.64 |       1.01 | 5.5e-06 |     178 |
+ | iso-true    |       222 |      4.5  |       1.26 | 4.4e-06 |    1821 |
+ | core-true   |       231 |      4.32 |       1.31 | 4.2e-06 |    1894 |
  +-------------+-----------+-----------+------------+---------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m IPCSystemOptions --module-startup >>):
 
- +----------------------+-----------+------------------------+------------+---------+---------+
- | participant          | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
- +----------------------+-----------+------------------------+------------+---------+---------+
- | IPC::System::Options |       6.6 |                    4.1 |       1    | 6.3e-06 |    1025 |
- | perl -e1 (baseline)  |       2.5 |                    0   |       2.64 | 2.5e-06 |     334 |
- +----------------------+-----------+------------------------+------------+---------+---------+
+ #table2#
+ +----------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | participant          | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
+ +----------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | IPC::System::Options | 1.25                         | 4.52               | 16.4           |     11.9  |                   6.03 |       1    | 1.2e-05 |     720 |
+ | perl -e1 (baseline)  | 0.824                        | 4.05               | 16             |      5.87 |                   0    |       2.03 | 5.8e-06 |     246 |
+ +----------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 
-=head1 DESCRIPTION
 
-Conclusion: Testing on my system (L<IPC::System::Options> 0.24, perl: 5.22.0,
-CPU: Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores)) shows the overhead to be
-~40μs (0.04ms) so for benchmarking commands that have overhead in the range of
-10-100ms we normally don't need to worry about the overhead of
-IPC::System::Option (0.04-0.4%) when we are using default precision (~1%).
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
 
 =head1 HOMEPAGE
 
@@ -160,7 +165,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
